@@ -165,19 +165,21 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
-import aws_cdk.aws_codebuild
-import aws_cdk.aws_codecommit
-import aws_cdk.aws_ec2
-import aws_cdk.aws_events
-import aws_cdk.aws_iam
-import aws_cdk.aws_lambda
-import constructs
+import aws_cdk.aws_codebuild as _aws_cdk_aws_codebuild_ceddda9d
+import aws_cdk.aws_codecommit as _aws_cdk_aws_codecommit_ceddda9d
+import aws_cdk.aws_ec2 as _aws_cdk_aws_ec2_ceddda9d
+import aws_cdk.aws_events as _aws_cdk_aws_events_ceddda9d
+import aws_cdk.aws_iam as _aws_cdk_aws_iam_ceddda9d
+import aws_cdk.aws_lambda as _aws_cdk_aws_lambda_ceddda9d
+import constructs as _constructs_77d1e7e8
 
 
 class PullRequestCheck(
-    constructs.Construct,
+    _constructs_77d1e7e8.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cloudcomponents/cdk-pull-request-check.PullRequestCheck",
 ):
@@ -185,24 +187,24 @@ class PullRequestCheck(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
-        build_spec: aws_cdk.aws_codebuild.BuildSpec,
-        repository: aws_cdk.aws_codecommit.IRepository,
+        build_spec: _aws_cdk_aws_codebuild_ceddda9d.BuildSpec,
+        repository: _aws_cdk_aws_codecommit_ceddda9d.IRepository,
         allow_all_outbound: typing.Optional[builtins.bool] = None,
-        artifacts: typing.Optional[aws_cdk.aws_codebuild.IArtifacts] = None,
-        build_image: typing.Optional[aws_cdk.aws_codebuild.IBuildImage] = None,
-        compute_type: typing.Optional[aws_cdk.aws_codebuild.ComputeType] = None,
-        environment_variables: typing.Optional[typing.Mapping[builtins.str, aws_cdk.aws_codebuild.BuildEnvironmentVariable]] = None,
+        artifacts: typing.Optional[_aws_cdk_aws_codebuild_ceddda9d.IArtifacts] = None,
+        build_image: typing.Optional[_aws_cdk_aws_codebuild_ceddda9d.IBuildImage] = None,
+        compute_type: typing.Optional[_aws_cdk_aws_codebuild_ceddda9d.ComputeType] = None,
+        environment_variables: typing.Optional[typing.Mapping[builtins.str, typing.Union[_aws_cdk_aws_codebuild_ceddda9d.BuildEnvironmentVariable, typing.Dict[builtins.str, typing.Any]]]] = None,
         post_comment: typing.Optional[builtins.bool] = None,
         privileged: typing.Optional[builtins.bool] = None,
         project_name: typing.Optional[builtins.str] = None,
-        role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
-        security_groups: typing.Optional[typing.Sequence[aws_cdk.aws_ec2.ISecurityGroup]] = None,
-        subnet_selection: typing.Optional[aws_cdk.aws_ec2.SubnetSelection] = None,
+        role: typing.Optional[_aws_cdk_aws_iam_ceddda9d.IRole] = None,
+        security_groups: typing.Optional[typing.Sequence[_aws_cdk_aws_ec2_ceddda9d.ISecurityGroup]] = None,
+        subnet_selection: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.SubnetSelection, typing.Dict[builtins.str, typing.Any]]] = None,
         update_approval_state: typing.Optional[builtins.bool] = None,
-        vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
+        vpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
     ) -> None:
         '''
         :param scope: -
@@ -223,6 +225,10 @@ class PullRequestCheck(
         :param update_approval_state: Indicates whether the approval state [APPROVE, REVOKE] should be updated. Default: true
         :param vpc: VPC network to place codebuild network interfaces. Specify this if the codebuild project needs to access resources in a VPC. Default: No VPC is specified
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__8a949cf0c5f2ee989cd28eb2b7a651f381ab0c2ffc744246c75a1ccfdc3c6f4c)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = PullRequestCheckProps(
             build_spec=build_spec,
             repository=repository,
@@ -244,11 +250,17 @@ class PullRequestCheck(
         jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="addToRolePolicy")
-    def add_to_role_policy(self, statement: aws_cdk.aws_iam.PolicyStatement) -> None:
+    def add_to_role_policy(
+        self,
+        statement: _aws_cdk_aws_iam_ceddda9d.PolicyStatement,
+    ) -> None:
         '''Add a permission only if there's a policy attached.
 
         :param statement: The permissions statement to add.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__4af0c07f0cfa1a66468005f9490ea21b4fa1d58105f2024a701a274c77cabfc2)
+            check_type(argname="argument statement", value=statement, expected_type=type_hints["statement"])
         return typing.cast(None, jsii.invoke(self, "addToRolePolicy", [statement]))
 
     @jsii.member(jsii_name="onCheckFailed")
@@ -256,88 +268,106 @@ class PullRequestCheck(
         self,
         id: builtins.str,
         *,
+        target: typing.Optional[_aws_cdk_aws_events_ceddda9d.IRuleTarget] = None,
+        cross_stack_scope: typing.Optional[_constructs_77d1e7e8.Construct] = None,
         description: typing.Optional[builtins.str] = None,
-        event_pattern: typing.Optional[aws_cdk.aws_events.EventPattern] = None,
+        event_pattern: typing.Optional[typing.Union[_aws_cdk_aws_events_ceddda9d.EventPattern, typing.Dict[builtins.str, typing.Any]]] = None,
         rule_name: typing.Optional[builtins.str] = None,
-        target: typing.Optional[aws_cdk.aws_events.IRuleTarget] = None,
-    ) -> aws_cdk.aws_events.Rule:
+    ) -> _aws_cdk_aws_events_ceddda9d.Rule:
         '''Defines an event rule which triggers when a check fails.
 
         :param id: -
+        :param target: The target to register for the event. Default: - No target is added to the rule. Use ``addTarget()`` to add a target.
+        :param cross_stack_scope: The scope to use if the source of the rule and its target are in different Stacks (but in the same account & region). This helps dealing with cycles that often arise in these situations. Default: - none (the main scope will be used, even for cross-stack Events)
         :param description: A description of the rule's purpose. Default: - No description
         :param event_pattern: Additional restrictions for the event to route to the specified target. The method that generates the rule probably imposes some type of event filtering. The filtering implied by what you pass here is added on top of that filtering. Default: - No additional filtering based on an event pattern.
         :param rule_name: A name for the rule. Default: AWS CloudFormation generates a unique physical ID.
-        :param target: The target to register for the event. Default: - No target is added to the rule. Use ``addTarget()`` to add a target.
         '''
-        options = aws_cdk.aws_events.OnEventOptions(
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__c8a688db551683f3d5e7f9fafea9addcadf98f0dd789f6b0c7bff013577b54e0)
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
+        options = _aws_cdk_aws_events_ceddda9d.OnEventOptions(
+            target=target,
+            cross_stack_scope=cross_stack_scope,
             description=description,
             event_pattern=event_pattern,
             rule_name=rule_name,
-            target=target,
         )
 
-        return typing.cast(aws_cdk.aws_events.Rule, jsii.invoke(self, "onCheckFailed", [id, options]))
+        return typing.cast(_aws_cdk_aws_events_ceddda9d.Rule, jsii.invoke(self, "onCheckFailed", [id, options]))
 
     @jsii.member(jsii_name="onCheckStarted")
     def on_check_started(
         self,
         id: builtins.str,
         *,
+        target: typing.Optional[_aws_cdk_aws_events_ceddda9d.IRuleTarget] = None,
+        cross_stack_scope: typing.Optional[_constructs_77d1e7e8.Construct] = None,
         description: typing.Optional[builtins.str] = None,
-        event_pattern: typing.Optional[aws_cdk.aws_events.EventPattern] = None,
+        event_pattern: typing.Optional[typing.Union[_aws_cdk_aws_events_ceddda9d.EventPattern, typing.Dict[builtins.str, typing.Any]]] = None,
         rule_name: typing.Optional[builtins.str] = None,
-        target: typing.Optional[aws_cdk.aws_events.IRuleTarget] = None,
-    ) -> aws_cdk.aws_events.Rule:
+    ) -> _aws_cdk_aws_events_ceddda9d.Rule:
         '''Defines an event rule which triggers when a check starts.
 
         :param id: -
+        :param target: The target to register for the event. Default: - No target is added to the rule. Use ``addTarget()`` to add a target.
+        :param cross_stack_scope: The scope to use if the source of the rule and its target are in different Stacks (but in the same account & region). This helps dealing with cycles that often arise in these situations. Default: - none (the main scope will be used, even for cross-stack Events)
         :param description: A description of the rule's purpose. Default: - No description
         :param event_pattern: Additional restrictions for the event to route to the specified target. The method that generates the rule probably imposes some type of event filtering. The filtering implied by what you pass here is added on top of that filtering. Default: - No additional filtering based on an event pattern.
         :param rule_name: A name for the rule. Default: AWS CloudFormation generates a unique physical ID.
-        :param target: The target to register for the event. Default: - No target is added to the rule. Use ``addTarget()`` to add a target.
         '''
-        options = aws_cdk.aws_events.OnEventOptions(
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__ba6557d7df5f9c9a57125d43faf0709ccb57bc32627d1ae0865e2029b773ffd7)
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
+        options = _aws_cdk_aws_events_ceddda9d.OnEventOptions(
+            target=target,
+            cross_stack_scope=cross_stack_scope,
             description=description,
             event_pattern=event_pattern,
             rule_name=rule_name,
-            target=target,
         )
 
-        return typing.cast(aws_cdk.aws_events.Rule, jsii.invoke(self, "onCheckStarted", [id, options]))
+        return typing.cast(_aws_cdk_aws_events_ceddda9d.Rule, jsii.invoke(self, "onCheckStarted", [id, options]))
 
     @jsii.member(jsii_name="onCheckSucceeded")
     def on_check_succeeded(
         self,
         id: builtins.str,
         *,
+        target: typing.Optional[_aws_cdk_aws_events_ceddda9d.IRuleTarget] = None,
+        cross_stack_scope: typing.Optional[_constructs_77d1e7e8.Construct] = None,
         description: typing.Optional[builtins.str] = None,
-        event_pattern: typing.Optional[aws_cdk.aws_events.EventPattern] = None,
+        event_pattern: typing.Optional[typing.Union[_aws_cdk_aws_events_ceddda9d.EventPattern, typing.Dict[builtins.str, typing.Any]]] = None,
         rule_name: typing.Optional[builtins.str] = None,
-        target: typing.Optional[aws_cdk.aws_events.IRuleTarget] = None,
-    ) -> aws_cdk.aws_events.Rule:
+    ) -> _aws_cdk_aws_events_ceddda9d.Rule:
         '''Defines an event rule which triggers when a check complets successfully.
 
         :param id: -
+        :param target: The target to register for the event. Default: - No target is added to the rule. Use ``addTarget()`` to add a target.
+        :param cross_stack_scope: The scope to use if the source of the rule and its target are in different Stacks (but in the same account & region). This helps dealing with cycles that often arise in these situations. Default: - none (the main scope will be used, even for cross-stack Events)
         :param description: A description of the rule's purpose. Default: - No description
         :param event_pattern: Additional restrictions for the event to route to the specified target. The method that generates the rule probably imposes some type of event filtering. The filtering implied by what you pass here is added on top of that filtering. Default: - No additional filtering based on an event pattern.
         :param rule_name: A name for the rule. Default: AWS CloudFormation generates a unique physical ID.
-        :param target: The target to register for the event. Default: - No target is added to the rule. Use ``addTarget()`` to add a target.
         '''
-        options = aws_cdk.aws_events.OnEventOptions(
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__bd31818559b40c612a0a219dba1955e327a10cb7b3c3873abc0ba8de66110b58)
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
+        options = _aws_cdk_aws_events_ceddda9d.OnEventOptions(
+            target=target,
+            cross_stack_scope=cross_stack_scope,
             description=description,
             event_pattern=event_pattern,
             rule_name=rule_name,
-            target=target,
         )
 
-        return typing.cast(aws_cdk.aws_events.Rule, jsii.invoke(self, "onCheckSucceeded", [id, options]))
+        return typing.cast(_aws_cdk_aws_events_ceddda9d.Rule, jsii.invoke(self, "onCheckSucceeded", [id, options]))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="codeBuildResultFunction")
     def code_build_result_function(
         self,
-    ) -> typing.Optional[aws_cdk.aws_lambda.IFunction]:
-        return typing.cast(typing.Optional[aws_cdk.aws_lambda.IFunction], jsii.get(self, "codeBuildResultFunction"))
+    ) -> typing.Optional[_aws_cdk_aws_lambda_ceddda9d.IFunction]:
+        return typing.cast(typing.Optional[_aws_cdk_aws_lambda_ceddda9d.IFunction], jsii.get(self, "codeBuildResultFunction"))
 
 
 @jsii.data_type(
@@ -365,21 +395,21 @@ class PullRequestCheckProps:
     def __init__(
         self,
         *,
-        build_spec: aws_cdk.aws_codebuild.BuildSpec,
-        repository: aws_cdk.aws_codecommit.IRepository,
+        build_spec: _aws_cdk_aws_codebuild_ceddda9d.BuildSpec,
+        repository: _aws_cdk_aws_codecommit_ceddda9d.IRepository,
         allow_all_outbound: typing.Optional[builtins.bool] = None,
-        artifacts: typing.Optional[aws_cdk.aws_codebuild.IArtifacts] = None,
-        build_image: typing.Optional[aws_cdk.aws_codebuild.IBuildImage] = None,
-        compute_type: typing.Optional[aws_cdk.aws_codebuild.ComputeType] = None,
-        environment_variables: typing.Optional[typing.Mapping[builtins.str, aws_cdk.aws_codebuild.BuildEnvironmentVariable]] = None,
+        artifacts: typing.Optional[_aws_cdk_aws_codebuild_ceddda9d.IArtifacts] = None,
+        build_image: typing.Optional[_aws_cdk_aws_codebuild_ceddda9d.IBuildImage] = None,
+        compute_type: typing.Optional[_aws_cdk_aws_codebuild_ceddda9d.ComputeType] = None,
+        environment_variables: typing.Optional[typing.Mapping[builtins.str, typing.Union[_aws_cdk_aws_codebuild_ceddda9d.BuildEnvironmentVariable, typing.Dict[builtins.str, typing.Any]]]] = None,
         post_comment: typing.Optional[builtins.bool] = None,
         privileged: typing.Optional[builtins.bool] = None,
         project_name: typing.Optional[builtins.str] = None,
-        role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
-        security_groups: typing.Optional[typing.Sequence[aws_cdk.aws_ec2.ISecurityGroup]] = None,
-        subnet_selection: typing.Optional[aws_cdk.aws_ec2.SubnetSelection] = None,
+        role: typing.Optional[_aws_cdk_aws_iam_ceddda9d.IRole] = None,
+        security_groups: typing.Optional[typing.Sequence[_aws_cdk_aws_ec2_ceddda9d.ISecurityGroup]] = None,
+        subnet_selection: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.SubnetSelection, typing.Dict[builtins.str, typing.Any]]] = None,
         update_approval_state: typing.Optional[builtins.bool] = None,
-        vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
+        vpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
     ) -> None:
         '''
         :param build_spec: Filename or contents of buildspec in JSON format.
@@ -399,8 +429,25 @@ class PullRequestCheckProps:
         :param vpc: VPC network to place codebuild network interfaces. Specify this if the codebuild project needs to access resources in a VPC. Default: No VPC is specified
         '''
         if isinstance(subnet_selection, dict):
-            subnet_selection = aws_cdk.aws_ec2.SubnetSelection(**subnet_selection)
-        self._values: typing.Dict[str, typing.Any] = {
+            subnet_selection = _aws_cdk_aws_ec2_ceddda9d.SubnetSelection(**subnet_selection)
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__5bc1bf70e305fd9bb3595817a8e563b683c482f51fbfc173ac902a5241512583)
+            check_type(argname="argument build_spec", value=build_spec, expected_type=type_hints["build_spec"])
+            check_type(argname="argument repository", value=repository, expected_type=type_hints["repository"])
+            check_type(argname="argument allow_all_outbound", value=allow_all_outbound, expected_type=type_hints["allow_all_outbound"])
+            check_type(argname="argument artifacts", value=artifacts, expected_type=type_hints["artifacts"])
+            check_type(argname="argument build_image", value=build_image, expected_type=type_hints["build_image"])
+            check_type(argname="argument compute_type", value=compute_type, expected_type=type_hints["compute_type"])
+            check_type(argname="argument environment_variables", value=environment_variables, expected_type=type_hints["environment_variables"])
+            check_type(argname="argument post_comment", value=post_comment, expected_type=type_hints["post_comment"])
+            check_type(argname="argument privileged", value=privileged, expected_type=type_hints["privileged"])
+            check_type(argname="argument project_name", value=project_name, expected_type=type_hints["project_name"])
+            check_type(argname="argument role", value=role, expected_type=type_hints["role"])
+            check_type(argname="argument security_groups", value=security_groups, expected_type=type_hints["security_groups"])
+            check_type(argname="argument subnet_selection", value=subnet_selection, expected_type=type_hints["subnet_selection"])
+            check_type(argname="argument update_approval_state", value=update_approval_state, expected_type=type_hints["update_approval_state"])
+            check_type(argname="argument vpc", value=vpc, expected_type=type_hints["vpc"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "build_spec": build_spec,
             "repository": repository,
         }
@@ -432,21 +479,21 @@ class PullRequestCheckProps:
             self._values["vpc"] = vpc
 
     @builtins.property
-    def build_spec(self) -> aws_cdk.aws_codebuild.BuildSpec:
+    def build_spec(self) -> _aws_cdk_aws_codebuild_ceddda9d.BuildSpec:
         '''Filename or contents of buildspec in JSON format.
 
         :see: https://docs.aws.amazon.com/codebuild/latest/userguide/build-spec-ref.html#build-spec-ref-example
         '''
         result = self._values.get("build_spec")
         assert result is not None, "Required property 'build_spec' is missing"
-        return typing.cast(aws_cdk.aws_codebuild.BuildSpec, result)
+        return typing.cast(_aws_cdk_aws_codebuild_ceddda9d.BuildSpec, result)
 
     @builtins.property
-    def repository(self) -> aws_cdk.aws_codecommit.IRepository:
+    def repository(self) -> _aws_cdk_aws_codecommit_ceddda9d.IRepository:
         '''The CodeCommit repository.'''
         result = self._values.get("repository")
         assert result is not None, "Required property 'repository' is missing"
-        return typing.cast(aws_cdk.aws_codecommit.IRepository, result)
+        return typing.cast(_aws_cdk_aws_codecommit_ceddda9d.IRepository, result)
 
     @builtins.property
     def allow_all_outbound(self) -> typing.Optional[builtins.bool]:
@@ -461,7 +508,7 @@ class PullRequestCheckProps:
         return typing.cast(typing.Optional[builtins.bool], result)
 
     @builtins.property
-    def artifacts(self) -> typing.Optional[aws_cdk.aws_codebuild.IArtifacts]:
+    def artifacts(self) -> typing.Optional[_aws_cdk_aws_codebuild_ceddda9d.IArtifacts]:
         '''Defines where build artifacts will be stored.
 
         Could be: PipelineBuildArtifacts, NoArtifacts and S3Artifacts.
@@ -469,19 +516,23 @@ class PullRequestCheckProps:
         :default: NoArtifacts
         '''
         result = self._values.get("artifacts")
-        return typing.cast(typing.Optional[aws_cdk.aws_codebuild.IArtifacts], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_codebuild_ceddda9d.IArtifacts], result)
 
     @builtins.property
-    def build_image(self) -> typing.Optional[aws_cdk.aws_codebuild.IBuildImage]:
+    def build_image(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_codebuild_ceddda9d.IBuildImage]:
         '''Build environment to use for the build.
 
         :default: BuildEnvironment.LinuxBuildImage.STANDARD_2_0
         '''
         result = self._values.get("build_image")
-        return typing.cast(typing.Optional[aws_cdk.aws_codebuild.IBuildImage], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_codebuild_ceddda9d.IBuildImage], result)
 
     @builtins.property
-    def compute_type(self) -> typing.Optional[aws_cdk.aws_codebuild.ComputeType]:
+    def compute_type(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_codebuild_ceddda9d.ComputeType]:
         '''The type of compute to use for this build.
 
         See the {@link ComputeType} enum for the possible values.
@@ -489,15 +540,15 @@ class PullRequestCheckProps:
         :default: taken from {@link #buildImage#defaultComputeType}
         '''
         result = self._values.get("compute_type")
-        return typing.cast(typing.Optional[aws_cdk.aws_codebuild.ComputeType], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_codebuild_ceddda9d.ComputeType], result)
 
     @builtins.property
     def environment_variables(
         self,
-    ) -> typing.Optional[typing.Mapping[builtins.str, aws_cdk.aws_codebuild.BuildEnvironmentVariable]]:
+    ) -> typing.Optional[typing.Mapping[builtins.str, _aws_cdk_aws_codebuild_ceddda9d.BuildEnvironmentVariable]]:
         '''The environment variables that your builds can use.'''
         result = self._values.get("environment_variables")
-        return typing.cast(typing.Optional[typing.Mapping[builtins.str, aws_cdk.aws_codebuild.BuildEnvironmentVariable]], result)
+        return typing.cast(typing.Optional[typing.Mapping[builtins.str, _aws_cdk_aws_codebuild_ceddda9d.BuildEnvironmentVariable]], result)
 
     @builtins.property
     def post_comment(self) -> typing.Optional[builtins.bool]:
@@ -534,15 +585,15 @@ class PullRequestCheckProps:
         return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
-    def role(self) -> typing.Optional[aws_cdk.aws_iam.IRole]:
+    def role(self) -> typing.Optional[_aws_cdk_aws_iam_ceddda9d.IRole]:
         '''The IAM service Role of the Project.'''
         result = self._values.get("role")
-        return typing.cast(typing.Optional[aws_cdk.aws_iam.IRole], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_iam_ceddda9d.IRole], result)
 
     @builtins.property
     def security_groups(
         self,
-    ) -> typing.Optional[typing.List[aws_cdk.aws_ec2.ISecurityGroup]]:
+    ) -> typing.Optional[typing.List[_aws_cdk_aws_ec2_ceddda9d.ISecurityGroup]]:
         '''What security group to associate with the codebuild project's network interfaces.
 
         If no security group is identified, one will be created automatically.
@@ -551,10 +602,12 @@ class PullRequestCheckProps:
         :default: Security group will be automatically created
         '''
         result = self._values.get("security_groups")
-        return typing.cast(typing.Optional[typing.List[aws_cdk.aws_ec2.ISecurityGroup]], result)
+        return typing.cast(typing.Optional[typing.List[_aws_cdk_aws_ec2_ceddda9d.ISecurityGroup]], result)
 
     @builtins.property
-    def subnet_selection(self) -> typing.Optional[aws_cdk.aws_ec2.SubnetSelection]:
+    def subnet_selection(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_ec2_ceddda9d.SubnetSelection]:
         '''Where to place the network interfaces within the VPC.
 
         Only used if 'vpc' is supplied.
@@ -562,7 +615,7 @@ class PullRequestCheckProps:
         :default: All private subnets
         '''
         result = self._values.get("subnet_selection")
-        return typing.cast(typing.Optional[aws_cdk.aws_ec2.SubnetSelection], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ec2_ceddda9d.SubnetSelection], result)
 
     @builtins.property
     def update_approval_state(self) -> typing.Optional[builtins.bool]:
@@ -574,7 +627,7 @@ class PullRequestCheckProps:
         return typing.cast(typing.Optional[builtins.bool], result)
 
     @builtins.property
-    def vpc(self) -> typing.Optional[aws_cdk.aws_ec2.IVpc]:
+    def vpc(self) -> typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc]:
         '''VPC network to place codebuild network interfaces.
 
         Specify this if the codebuild project needs to access resources in a VPC.
@@ -582,7 +635,7 @@ class PullRequestCheckProps:
         :default: No VPC is specified
         '''
         result = self._values.get("vpc")
-        return typing.cast(typing.Optional[aws_cdk.aws_ec2.IVpc], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -602,3 +655,89 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__8a949cf0c5f2ee989cd28eb2b7a651f381ab0c2ffc744246c75a1ccfdc3c6f4c(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    build_spec: _aws_cdk_aws_codebuild_ceddda9d.BuildSpec,
+    repository: _aws_cdk_aws_codecommit_ceddda9d.IRepository,
+    allow_all_outbound: typing.Optional[builtins.bool] = None,
+    artifacts: typing.Optional[_aws_cdk_aws_codebuild_ceddda9d.IArtifacts] = None,
+    build_image: typing.Optional[_aws_cdk_aws_codebuild_ceddda9d.IBuildImage] = None,
+    compute_type: typing.Optional[_aws_cdk_aws_codebuild_ceddda9d.ComputeType] = None,
+    environment_variables: typing.Optional[typing.Mapping[builtins.str, typing.Union[_aws_cdk_aws_codebuild_ceddda9d.BuildEnvironmentVariable, typing.Dict[builtins.str, typing.Any]]]] = None,
+    post_comment: typing.Optional[builtins.bool] = None,
+    privileged: typing.Optional[builtins.bool] = None,
+    project_name: typing.Optional[builtins.str] = None,
+    role: typing.Optional[_aws_cdk_aws_iam_ceddda9d.IRole] = None,
+    security_groups: typing.Optional[typing.Sequence[_aws_cdk_aws_ec2_ceddda9d.ISecurityGroup]] = None,
+    subnet_selection: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.SubnetSelection, typing.Dict[builtins.str, typing.Any]]] = None,
+    update_approval_state: typing.Optional[builtins.bool] = None,
+    vpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__4af0c07f0cfa1a66468005f9490ea21b4fa1d58105f2024a701a274c77cabfc2(
+    statement: _aws_cdk_aws_iam_ceddda9d.PolicyStatement,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__c8a688db551683f3d5e7f9fafea9addcadf98f0dd789f6b0c7bff013577b54e0(
+    id: builtins.str,
+    *,
+    target: typing.Optional[_aws_cdk_aws_events_ceddda9d.IRuleTarget] = None,
+    cross_stack_scope: typing.Optional[_constructs_77d1e7e8.Construct] = None,
+    description: typing.Optional[builtins.str] = None,
+    event_pattern: typing.Optional[typing.Union[_aws_cdk_aws_events_ceddda9d.EventPattern, typing.Dict[builtins.str, typing.Any]]] = None,
+    rule_name: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__ba6557d7df5f9c9a57125d43faf0709ccb57bc32627d1ae0865e2029b773ffd7(
+    id: builtins.str,
+    *,
+    target: typing.Optional[_aws_cdk_aws_events_ceddda9d.IRuleTarget] = None,
+    cross_stack_scope: typing.Optional[_constructs_77d1e7e8.Construct] = None,
+    description: typing.Optional[builtins.str] = None,
+    event_pattern: typing.Optional[typing.Union[_aws_cdk_aws_events_ceddda9d.EventPattern, typing.Dict[builtins.str, typing.Any]]] = None,
+    rule_name: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__bd31818559b40c612a0a219dba1955e327a10cb7b3c3873abc0ba8de66110b58(
+    id: builtins.str,
+    *,
+    target: typing.Optional[_aws_cdk_aws_events_ceddda9d.IRuleTarget] = None,
+    cross_stack_scope: typing.Optional[_constructs_77d1e7e8.Construct] = None,
+    description: typing.Optional[builtins.str] = None,
+    event_pattern: typing.Optional[typing.Union[_aws_cdk_aws_events_ceddda9d.EventPattern, typing.Dict[builtins.str, typing.Any]]] = None,
+    rule_name: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__5bc1bf70e305fd9bb3595817a8e563b683c482f51fbfc173ac902a5241512583(
+    *,
+    build_spec: _aws_cdk_aws_codebuild_ceddda9d.BuildSpec,
+    repository: _aws_cdk_aws_codecommit_ceddda9d.IRepository,
+    allow_all_outbound: typing.Optional[builtins.bool] = None,
+    artifacts: typing.Optional[_aws_cdk_aws_codebuild_ceddda9d.IArtifacts] = None,
+    build_image: typing.Optional[_aws_cdk_aws_codebuild_ceddda9d.IBuildImage] = None,
+    compute_type: typing.Optional[_aws_cdk_aws_codebuild_ceddda9d.ComputeType] = None,
+    environment_variables: typing.Optional[typing.Mapping[builtins.str, typing.Union[_aws_cdk_aws_codebuild_ceddda9d.BuildEnvironmentVariable, typing.Dict[builtins.str, typing.Any]]]] = None,
+    post_comment: typing.Optional[builtins.bool] = None,
+    privileged: typing.Optional[builtins.bool] = None,
+    project_name: typing.Optional[builtins.str] = None,
+    role: typing.Optional[_aws_cdk_aws_iam_ceddda9d.IRole] = None,
+    security_groups: typing.Optional[typing.Sequence[_aws_cdk_aws_ec2_ceddda9d.ISecurityGroup]] = None,
+    subnet_selection: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.SubnetSelection, typing.Dict[builtins.str, typing.Any]]] = None,
+    update_approval_state: typing.Optional[builtins.bool] = None,
+    vpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
